from datetime import datetime
import time
import json

def naver_trend_to_json(trend_text):
    list = trend_text.split("\n")
    ymd = list[0].split(".")  # 년월일의 list
    hms = list[1].split(" ")[0].split(":"); #시간 분 초 의 list
    d = datetime(int(ymd[0]),int(ymd[1]),int(ymd[2]), int(hms[0]), int(hms[1]),int(hms[2].split(" ")[0]))
    unixtime = int(time.mktime(d.timetuple()))
    dic = {}
    dic1 = {}
    for idx in range(2,len(list)):
        a = list[idx].split(" ")
        # print(a)
        dic1[a[0]]= list[idx].split(a[0]+" ")[1]

    dic[str(unixtime)] = dic1
    j = json.dumps(dic,ensure_ascii=False)
    return j


# coding: utf-8

"""
    blu-trend

    This is a package for get trend

    OpenAPI spec version: 0.0.6
    Contact: originman@bluehack.net
"""

from setuptools import setup, find_packages

NAME = "blu-trend"
VERSION = "0.0.6"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["selenium"
            "chromedrvier-binary"]

setup(
    name=NAME,
    version=VERSION,
    description="get trend package",
    author_email="originman@bluehack.net",
    url="",
    keywords=["blu", "blu-trend"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    """
)



from selenium import webdriver
from blu_trend import trend_to_json_parser
import chromedriver_binary
import platform


TEST_URL = 'https://datalab.naver.com/keyword/realtimeList.naver?where=main'
options = webdriver.ChromeOptions()
options.add_argument('headless')
options.add_argument('window-size=1920x1080')
options.add_argument("disable-gpu")

# UserAgent값을 바꿔줍시다!
options.add_argument("user-agent=Mozilla/5.0 (Macintosh; Intel Mac OS X 10_12_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/61.0.3163.100 Safari/537.36")
driver = None;
os_name = platform.system()
driver = webdriver.Chrome(chrome_options=options)
driver.get(TEST_URL)
xxx = driver.find_element_by_css_selector("div[class='keyword_rank select_date']")
def save_json_trend():
    j = trend_to_json_parser.naver_trend_to_json(xxx.text)
    f = open("naver_trend.json", 'w')
    f.write(j)
    f.close()

















